# Smallest AI plugin for LiveKit Agents

Support for speech synthesis with the [Smallest AI](https://smallest.ai/) API.

See the [Smallest AI TTS integration docs](https://docs.livekit.io/agents/models/tts/smallestai/) for more information.

## Installation

```bash
pip install livekit-plugins-smallestai
```

## Pre-requisites

You'll need an API key from Smallest AI. It can be set as an environment variable: `SMALLEST_API_KEY`
